@@ -1,9 +1,9 @@
 package Calendar::Indonesia::Holiday;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-12-04'; # DATE
+our $DATE = '2020-12-08'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.329'; # VERSION
+our $VERSION = '0.330'; # VERSION
 
 use 5.010001;
 use strict;
@@ -832,6 +832,7 @@ my %year_holidays;
         # - independence day
         ($hijra2020 = _h_hijra     ({_expand_dm("20-08")}, {hyear=>1442})),
         ($mawlid2020 = _h_mawlid({_expand_dm("29-10")}, {hyear=>1442})),
+        _h_jrelection({_expand_dm("09-12")}, {decree_date => "2015-11-27"}), # keppres 20/2020 (2020-11-27), surat edaran menaker m/14/hk.04/xii/2020 (2020-12-07)
         # - christmas
     ];
 
@@ -883,6 +884,32 @@ my %year_holidays;
     );
 }
 
+L2022: {
+    # 2022 holidays
+    1;
+}
+
+{
+    # 2023 holidays
+    1;
+}
+
+{
+    # 2024 holidays
+    1;
+}
+
+{
+    # 2025 holidays
+    #_h_jrelection({_expand_dm("09-12")}, {decree_date => "2025-11-xx"}), # keppres xx/2025, surat edaran menaker xxx.../2020 (2020-12-xx)
+    1;
+}
+
+{
+    # 2026 holidays
+    1;
+}
+
 
 my @years     = sort keys %year_holidays;
 our $min_year = $years[0];
@@ -1207,7 +1234,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.329 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2020-12-04.
+This document describes version 0.330 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2020-12-08.
 
 =head1 SYNOPSIS
 
